{% load static i18n %}<!DOCTYPE html>
<html lang="en">
  <head>
    <meta charset="utf-8">
    <meta http-equiv="x-ua-compatible" content="ie=edge">
    <title>{% block title %}acp_calendar_project{% endblock title %}</title>
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <meta name="description" content="">
    <meta name="author" content="">

    <!-- HTML5 shim, for IE6-8 support of HTML5 elements -->
    <!--[if lt IE 9]>
      <script src="https://html5shim.googlecode.com/svn/trunk/html5.js"></script>
    <![endif]-->

    {% block css %}
    <!-- Latest compiled and minified CSS -->
    <link rel="stylesheet" href="https://maxcdn.bootstrapcdn.com/bootstrap/4.0.0-alpha.2/css/bootstrap.min.css" integrity="sha384-y3tfxAZXuh4HwSYylfB+J125MxIs6mR5FOHamPBG064zB+AFeWH94NdvaCBm8qnd" crossorigin="anonymous">
    <link rel="stylesheet" href="//code.jquery.com/ui/1.12.1/themes/base/jquery-ui.css">
    <!-- Your stuff: Third-party css libraries go here -->

    <!-- This file store project specific CSS -->
    <link href="{% static 'css/project.css' %}" rel="stylesheet">
    {% endblock %}

  </head>

  <body>

    <div class="m-b">
      <nav class="navbar navbar-dark navbar-static-top bg-inverse">
        <div class="container">
          <a class="navbar-brand" href="/">ACP Calendar Test</a>
          <button type="button" class="navbar-toggler hidden-sm-up pull-xs-right" data-toggle="collapse" data-target="#bs-navbar-collapse-1">
            &#9776;
          </button>

          <!-- Collect the nav links, forms, and other content for toggling -->
          <div class="collapse navbar-toggleable-xs" id="bs-navbar-collapse-1">
            <ul class="nav navbar-nav">
              <li class="nav-item">
                <a class="nav-link" href="#">Home</a>
              </li>
              <li class="nav-item">
                <a class="nav-link" href="#">About</a>
              </li>
            </ul>

            <ul class="nav navbar-nav pull-xs-right">
              {% if request.user.is_authenticated %}
                <li class="nav-item">
                  <a class="nav-link" href="#">{% trans "My Profile" %}</a>
                </li>
                <li class="nav-item">
                  <a class="nav-link" href="#">{% trans "Logout" %}</a>
                </li>
              {% else %}
                <li class="nav-item">
                  <a id="sign-up-link" class="nav-link" href="#">{% trans "Sign Up" %}</a>
                </li>
                <li class="nav-item">
                  <a id="log-in-link" class="nav-link" href="#">{% trans "Log In" %}</a>
                </li>
              {% endif %}
            </ul>
          </div>
        </div>
      </nav>
    </div>

    <div class="container">

      {% if messages %}
          {% for message in messages %}
              <div class="alert {% if message.tags %}alert-{{ message.tags }}{% endif %}">{{ message }}</div>
          {% endfor %}
      {% endif %}

      {% block content %}
        <p>Use this document as a way to quick start any new project.</p>
      {% endblock content %}

    </div> <!-- /container -->

    {% block modal %}{% endblock modal %}

    <!-- Le javascript
    ================================================== -->
    <!-- Placed at the end of the document so the pages load faster -->
    {% block javascript %}
      <!-- Latest JQuery -->
      <script src="https://ajax.googleapis.com/ajax/libs/jquery/2.2.0/jquery.min.js"></script>

      <!-- Tether - a requirement for Bootstrap tooltips -->
      <script src="https://cdnjs.cloudflare.com/ajax/libs/tether/1.2.0/js/tether.min.js"></script>

      <!-- Latest compiled and minified JavaScript -->
      <script src="https://maxcdn.bootstrapcdn.com/bootstrap/4.0.0-alpha.2/js/bootstrap.min.js" integrity="sha384-vZ2WRJMwsjRMW/8U7i6PWi6AlO1L79snBrmgiDpgIWJ82z8eA5lenwvxbMV1PAh7" crossorigin="anonymous"></script>

      <!-- Your stuff: Third-party javascript libraries go here -->

  <script src="https://code.jquery.com/ui/1.12.1/jquery-ui.js"></script>
      <!-- place project specific Javascript in this file -->
      <script src="{% static 'js/project.js' %}"></script>
    {% endblock javascript %}
  </body>
</html>

