<div class="col-md-4 month">
    <div class="bg-primary month-title">
        {{ month.month }}, {{ month.year }}
    </div>
    <div class="month-data">{{ month.working_days }} working days</div>
</div>
